local Mockingbird = ...


---------------
--set up
---------------
Mockingbird:registerEnumValue( "RESOURCE_TYPE", "RESOURCE_MOONSHINE" )
Mockingbird:registerAssetId("icons/Moonshine.png", "ICON_MOONSHINE")


---------------
-- New Resource Moonshine 
---------------

Mockingbird:register({
    DataType = "RESOURCE",
    Id = "RESOURCE_MOONSHINE",
    ResourceName = "RESOURCE_MOONSHINE_NAME",
	OrderId = 15,
    Icon = "ICON_MOONSHINE",
    ResourceTypeList = { "LUXURY", "RESOURCE_MOONSHINE" },
    IsTradable = true,
    ResourceLayoutType = "CRATES",
    VillagerBuyingPrice = { Resource = "GOLD", Quantity = 1 },
    DisplayInInventory = true
})
---------------
-- Asset IDs --
---------------

Mockingbird:registerAssetId("models/markets.fbx/Prefab/Abar_Part", "PREFAB_ABAR_PART")

Mockingbird:registerAssetId("models/containers.fbx/Prefab/Ajug_Part", "PREFAB_AJUG_PART")

--Outfits
Mockingbird:registerAssetId("models/outfits.fbx/Prefab/BFemaleFront", "PREFAB_MOONSHINE_FEMALE_FRONT")
Mockingbird:registerAssetId("models/outfits.fbx/Prefab/BFemaleBelt", "PREFAB_MOONSHINE_FEMALE_BELT")
Mockingbird:registerAssetId("models/outfits.fbx/Prefab/BMaleFront", "PREFAB_MOONSHINE_MALE_FRONT")


--------------------
-- Scaling Building Parts --
--------------------


Mockingbird:registerAssetId("models/containers.fbx/Prefab/Ajug_Part", "PREFAB_AJUG_PART")

Mockingbird:register({ 
    DataType = "BUILDING_FUNCTION_RESOURCE_GENERATOR",
    Id = "MOONSHINE_GENERATOR_FUNCTION",
    ResourceGenerated = "RESOURCE_MOONSHINE",
    IsForConsumer = true,
    IsInfinite = false
})

Mockingbird:register({
	DataType = "BUILDING_PART",
	Id = "AJUG_PART",
	Name = "AJUG_NAME",
	Description = "AJUG_DESC",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER",
		CoreObjectPrefab = "PREFAB_ROOT_PART",
		EndPart = "AJUG",
		FillerList = {
			"TILING"
    	},
		BasementFillerList = {
			"TILING"
       	},
		MinimumScale = 2,
		IsVertical = true
	},
AssetBuildingFunction = "MOONSHINE_GENERATOR_FUNCTION"
})
Mockingbird:register({
	DataType = "BUILDING_PART",
	Id = "AJUG",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_AJUG_PART"
	}
})





---------------
-- Building Part: Moonshine Bar --
---------------
Mockingbird:register({
    DataType = "BUILDING_PART",
    Id = "ABAR_PART",
    Name = "ABAR_NAME",
    Description = "ABAR_DESC",
    IsMovableWhenBuilt = true,
    ConstructorData = {
        DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_ABAR_PART"
    },
	BuildingZone = {
		ZoneEntryList = {
			{
				Type = {
					DEFAULT = true,
					NAVIGABLE = false
				},
				Polygon = polygon.createCircle( 0.4, {0, 0}, 8 )
			}
		}
	},
	AssetBuildingFunction = "BUILDING_FUNCTION_MOONSHINER",		
		DesirabilityModifiers = {
		{
			Desirability = "DESIRABILITY_RESIDENTIAL",
			Type = "ADD",
			Radius = 20.0,
			Value = 0.5
		}
	}
})
---------------
-- Building Function: Moonshiners bar --
---------------
Mockingbird:register({
    DataType = "BUILDING_FUNCTION_MARKET",
    Id = "BUILDING_FUNCTION_MOONSHINER",
    Name = "BUILDING_FUNCTION_MOONSHINER_NAME",
    IsPrivate = false,
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "JOB_MOONSHINER", 
        Behavior = "BEHAVIOR_WORK"
    },
    TypeList = { "RESOURCE_MOONSHINE" },
    IsOverrideCapacity = true,
    CapacityPerSlot = 50,
    InputInventoryCapacity = {
    },
    ResourceListNeeded = {
    },
    ResourceProduced = {
        { Resource = "RESOURCE_MOONSHINE", Quantity = 1 },
    }
})
---------------
-- Job: MOONSHINER --
---------------
Mockingbird:register({
	DataType = "JOB",
	Id = "JOB_MOONSHINER",
	JobName = "JOB_MOONSHINER_NAME",
	JobDescription = "JOB_MOONSHINER_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
	-- UseWorkplaceBehavior = true,
    ProductionDelay = 20.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP", 
--		LeftHandObject = {
--		Model = "PREFAB_TOOL_WINE_MAKER_STICK",
--		WorkAttachName = "Scroll_Anchor", 
--		WalkAttachName = "Scroll_Anchor"
--	},
      FemaleFrontList = {
            "PREFAB_MOONSHINE_FEMALE_FRONT",
        },
       FemaleBeltList = {
            "PREFAB_MOONSHINE_FEMALE_BELT",
        },     
        MaleFrontList = {
             "PREFAB_MOONSHINE_MALE_FRONT",
        },
		WalkAnimation = "WALKING",
		IdleAnimation = "MARKET_TENDER"
	}
})

Mockingbird:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MOONSHINER"
    }
})

Mockingbird:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MOONSHINER"
    }
})

Mockingbird:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MOONSHINER"
    }
})

Mockingbird:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MOONSHINER"
    }
})